@@ -255,8 +255,8 @@ private:
     void               commandErrorMsg(const ShellProcess*, const KAEvent&, const KAAlarm*, int flags = 0, const QStringList& errmsgs = QStringList());
     void               purge(int daysToKeep);
     QStringList        scheduledAlarmList();
-    void               setEventCommandError(const KAEvent&, KAEvent::CmdErrType) const;
-    void               clearEventCommandError(const KAEvent&, KAEvent::CmdErrType) const;
+    void               setEventCommandError(const KAEvent&, KAEvent::CmdErr) const;
+    void               clearEventCommandError(const KAEvent&, KAEvent::CmdErr) const;
     ProcData*          findCommandProcess(const QString& eventId) const;
 
     static KAlarmApp*  mInstance;               // the one and only KAlarmApp instance
@@ -275,10 +275,10 @@ private:
     QColor             mPrefsArchivedColour;    // archived alarms text colour
     int                mArchivedPurgeDays {-1}; // how long to keep archived alarms, 0 = don't keep, -1 = keep indefinitely
     int                mPurgeDaysQueued {-1};   // >= 0 to purge the archive calendar from KAlarmApp::processLoop()
-    QVector<ResourceId> mPendingPurges;         // new resources which may need to be purged when populated
-    QVector<ProcData*>  mCommandProcesses;      // currently active command alarm processes
+    QList<ResourceId>  mPendingPurges;          // new resources which may need to be purged when populated
+    QList<ProcData*>   mCommandProcesses;       // currently active command alarm processes
     QQueue<ActionQEntry> mActionQueue;          // queued commands and actions
-    QVector<MessageWindow*> mRestoredWindows;   // message windows restored at startup, waiting to be displayed
+    QList<MessageWindow*> mRestoredWindows;     // message windows restored at startup, waiting to be displayed
     int                mEditingCmdLineAlarm {0}; // whether currently editing alarm specified on command line
     int                mPendingQuitCode;        // exit code for a pending quit
     bool               mPendingQuit {false};    // quit once the D-Bus command and shell command queues have been processed
